==> nextcloud-29.0.12.tar.bz2: nextcloud/apps/password_policy/l10n/sr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Лозинка је истекла, користите исти начин као када заборавите лозинку да је ресетујете",
    "Password must not have been used recently before." : "Лозинка не сме да је скорије коришћена.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Лозинка је међу 1.000.000 најкоришћенијих лозинки. Одаберите неку мало јединственију.",
    "Password is present in compromised password list. Please choose a different password." : "Лозинка је међу најчешће проваљеним лозинкама. Одаберите неку другу.",
    "Password needs to be at least %s characters long." : "Потребно је да лозинка буде дугачка барем %s карактера.",
    "Password needs to contain at least one numeric character." : "Лозинка мора да има бар једну цифру.",
    "Password needs to contain at least one special character." : "Лозинка мора да садржи бар један специјални карактер.",
    "Password needs to contain at least one lower and one upper case character." : "Лозинка мора да има бар једно мало и бар једно велико слово.",
    "Password policy" : "Правила за лозинке",
    "Allows admins to configure a password policy" : "Омогућава администраторима да подесе смернице за лозинке",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Омогућава администратору да одреди предуслове за лозинке, нпр. да захтева минималну дужину",
    "General password policies" : "Опште полисе лозинке",
    "Add policy set" : "Додај скуп полиси",
    "Login policies" : "Полисе за пријаву",
    "Password history size" : "Величина историје лозинки",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Број лозинки који се чува (безбедно хеширане) да се корисници спрече да поново употребљавају раније коришћене лозинке.",
    "Maximum login attempts" : "Максимални број покушаја пријаве",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Број покушаја пријаве пре него што се кориснички налог блокира све до ручне интервенције. (0 без ограничења)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Молимо вас да имате на уму да је намена ове опција заштита нападнутих налога. Администрација мора поново ручно да укључи искључене налоге. Заштита од грубе силе ће блокирати IP адресе нападача који покушавају да погоде лозинке налога, независно од овог подешавања.",
    "Number of days until user password expires" : "Број дана до истека важења коринискове лозинке",
    "Password expiration" : "Рок трајања лозинке",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Упозорење: у данашње време неколико безбедносних агенција сматра  да је укључивање датума истека лозинке безбедносни ризик.",
    "Remove policy" : "Уклони полису",
    "Minimum password length" : "Минимална дужина лозинке",
    "Forbid common passwords" : "Забрани честе лозинке",
    "Enforce upper and lower case characters" : "Захтевај употребу и малих и великих слова",
    "Enforce numeric characters" : "Захтевај употребу цифри",
    "Enforce special characters" : "Захтевај употребу специјалних карактера",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Провери лозинке на листи најчешће проваљиваних лозинки на сајту haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Ова провера прави хеш лозинке и шаље првих 5 карактера хеша на haveibeenpwned.com да дохвати све хешеве који почињу исто тако. Онда проверава на Некстклауд инстанци да ли је Ваш хеш у листи враћених хешева.",
    "Account password policies" : "Полисе за лозинку налога",
    "Share password policies" : "Полисе за лозинке дељења",
    "User password history" : "Користи историјат лозинки",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Молимо вас да имате на уму да је намена ове опција заштита нападнутих налога. Администрација мора поново ручно да укључи искључене налоге. Заштита од грубе силе ће блокирати IP адресе нападача који покушавају да погоде лозинке налога, независно од овог подешавања.",
    "Unknown error" : "Непозната грешка",
    "Minimal length has to be a non negative number" : "Минимална дужина не сме да буде негативан број",
    "History size has to be a non negative number" : "Величина историје не сме да буде негативан број",
    "Expiration days have to be a non negative number" : "Дани истицања не смеју да буду негативан број",
    "Maximum login attempts have to be a non negative number" : "Максимални број покушаја пријаве не сме да буде негативан број",
    "Settings saved" : "Поставке сачуване",
    "Error while saving settings" : "Грешка приликом чувања подешавања"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-29.0.14.tar.bz2: nextcloud/apps/password_policy/l10n/sr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Лозинка је истекла, користите исти начин као када заборавите лозинку да је ресетујете",
    "Password must not have been used recently before." : "Лозинка не сме да је скорије коришћена.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Лозинка је међу 1.000.000 најкоришћенијих лозинки. Одаберите неку мало јединственију.",
    "Password is present in compromised password list. Please choose a different password." : "Лозинка је међу најчешће проваљеним лозинкама. Одаберите неку другу.",
    "Password needs to be at least %s characters long." : "Потребно је да лозинка буде дугачка барем %s карактера.",
    "Password needs to contain at least one numeric character." : "Лозинка мора да има бар једну цифру.",
    "Password needs to contain at least one special character." : "Лозинка мора да садржи бар један специјални карактер.",
    "Password needs to contain at least one lower and one upper case character." : "Лозинка мора да има бар једно мало и бар једно велико слово.",
    "Password policy" : "Правила за лозинке",
    "Allows admins to configure a password policy" : "Омогућава администраторима да подесе смернице за лозинке",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Омогућава администратору да одреди предуслове за лозинке, нпр. да захтева минималну дужину",
    "General password policies" : "Опште полисе лозинке",
    "Add policy set" : "Додај скуп полиси",
    "Login policies" : "Полисе за пријаву",
    "Password history size" : "Величина историје лозинки",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Број лозинки који се чува (безбедно хеширане) да се корисници спрече да поново употребљавају раније коришћене лозинке.",
    "Maximum login attempts" : "Максимални број покушаја пријаве",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Број покушаја пријаве пре него што се кориснички налог блокира све до ручне интервенције. (0 без ограничења)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Молимо вас да имате на уму да је намена ове опција заштита нападнутих налога. Администрација мора поново ручно да укључи искључене налоге. Заштита од грубе силе ће блокирати IP адресе нападача који покушавају да погоде лозинке налога, независно од овог подешавања.",
    "Number of days until user password expires" : "Број дана до истека важења коринискове лозинке",
    "Password expiration" : "Рок трајања лозинке",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Упозорење: у данашње време неколико безбедносних агенција сматра  да је укључивање датума истека лозинке безбедносни ризик.",
    "Remove policy" : "Уклони полису",
    "Minimum password length" : "Минимална дужина лозинке",
    "Forbid common passwords" : "Забрани честе лозинке",
    "Enforce upper and lower case characters" : "Захтевај употребу и малих и великих слова",
    "Enforce numeric characters" : "Захтевај употребу цифри",
    "Enforce special characters" : "Захтевај употребу специјалних карактера",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Провери лозинке на листи најчешће проваљиваних лозинки на сајту haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Ова провера прави хеш лозинке и шаље првих 5 карактера хеша на haveibeenpwned.com да дохвати све хешеве који почињу исто тако. Онда проверава на Некстклауд инстанци да ли је Ваш хеш у листи враћених хешева.",
    "Account password policies" : "Полисе за лозинку налога",
    "Share password policies" : "Полисе за лозинке дељења",
    "Unknown error" : "Непозната грешка",
    "Minimal length has to be a non negative number" : "Минимална дужина не сме да буде негативан број",
    "History size has to be a non negative number" : "Величина историје не сме да буде негативан број",
    "Expiration days have to be a non negative number" : "Дани истицања не смеју да буду негативан број",
    "Maximum login attempts have to be a non negative number" : "Максимални број покушаја пријаве не сме да буде негативан број",
    "Settings saved" : "Поставке сачуване",
    "Error while saving settings" : "Грешка приликом чувања подешавања",
    "User password history" : "Користи историјат лозинки",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Молимо вас да имате на уму да је намена ове опција заштита нападнутих налога. Администрација мора поново ручно да укључи искључене налоге. Заштита од грубе силе ће блокирати IP адресе нападача који покушавају да погоде лозинке налога, независно од овог подешавања."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
